// Copyright (C) 2009 Playedit.

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef ID3TAG_READ_H
#define ID3TAG_READ_H

#include <glibmm/ustring.h>
#include <mpg123.h>
#include <stdint.h>

class ID3TagReader
{
	public:
		ID3TagReader(const std::string& filename);
		~ID3TagReader();

		bool Load();

		Glib::ustring GetTitle();
		Glib::ustring GetArtist();
		Glib::ustring GetAlbum();
		Glib::ustring GetGenre();
		Glib::ustring GetYear();
		uint16_t GetTrackNumber();
		uint16_t GetNumChannels();
		uint32_t GetDuration();

	private:
		class ID3File
		{
			public:
				ID3File(mpg123_handle* handle, const std::string& filename);
				~ID3File();
				inline operator bool() { return m_IsValid; };

			private:
				mpg123_handle* m_Handle;
				bool m_IsValid;
		};

		mpg123_handle* m_Handle;
		std::string m_FileName;
		mpg123_id3v1 *m_ID3v1;
		mpg123_id3v2 *m_ID3v2;

		bool m_HaveID3;
		uint16_t m_NumChannels;
		uint32_t m_Duration;

		static bool mpg123_inited;
};

#endif // ID3TAG_READ_H
